package
module
Version:
v0.0.0-...-fc3f981
Opens a new window with list of versions in this module.
Published: Jan 20, 2015
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
GoRelic
NewRelic middleware for gin-gonic framework.
Usage
import(
"github.com/go-go/gin"
"github.com/go-go/gin-gorelic"
)
func main(){
g := gin.Default()
gorelic.InitNewrelicAgent("YOUR_NEWRELIC_LICENSE_KEY", "YOUR_APPLICATION_NAME", true)
g.Use(gorelic.Handler)
g.Run()
}
Authors
Documentation
¶
InitNewrelicAgent creates the new relic agent
Source Files
¶
Click to show internal directories.
Click to hide internal directories.